# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEmails:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send_monthly_digest(self, client: AlphaxivCat) -> None:
        email = client.admin.v1.emails.send_monthly_digest()
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send_monthly_digest_with_all_params(self, client: AlphaxivCat) -> None:
        email = client.admin.v1.emails.send_monthly_digest(
            role="admin",
        )
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_send_monthly_digest(self, client: AlphaxivCat) -> None:
        response = client.admin.v1.emails.with_raw_response.send_monthly_digest()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_send_monthly_digest(self, client: AlphaxivCat) -> None:
        with client.admin.v1.emails.with_streaming_response.send_monthly_digest() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = response.parse()
            assert email is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send_weekly_digest(self, client: AlphaxivCat) -> None:
        email = client.admin.v1.emails.send_weekly_digest()
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send_weekly_digest_with_all_params(self, client: AlphaxivCat) -> None:
        email = client.admin.v1.emails.send_weekly_digest(
            events=[
                {
                    "date": "date",
                    "description": "description",
                    "link": "link",
                    "title": "title",
                    "end_time_raw": "endTimeRaw",
                    "start_time_raw": "startTimeRaw",
                }
            ],
            intro_text="introText",
            role="admin",
            subject="subject",
        )
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_send_weekly_digest(self, client: AlphaxivCat) -> None:
        response = client.admin.v1.emails.with_raw_response.send_weekly_digest()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_send_weekly_digest(self, client: AlphaxivCat) -> None:
        with client.admin.v1.emails.with_streaming_response.send_weekly_digest() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = response.parse()
            assert email is None

        assert cast(Any, response.is_closed) is True


class TestAsyncEmails:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send_monthly_digest(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.admin.v1.emails.send_monthly_digest()
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send_monthly_digest_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.admin.v1.emails.send_monthly_digest(
            role="admin",
        )
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_send_monthly_digest(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.admin.v1.emails.with_raw_response.send_monthly_digest()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_send_monthly_digest(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.admin.v1.emails.with_streaming_response.send_monthly_digest() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = await response.parse()
            assert email is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send_weekly_digest(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.admin.v1.emails.send_weekly_digest()
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send_weekly_digest_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.admin.v1.emails.send_weekly_digest(
            events=[
                {
                    "date": "date",
                    "description": "description",
                    "link": "link",
                    "title": "title",
                    "end_time_raw": "endTimeRaw",
                    "start_time_raw": "startTimeRaw",
                }
            ],
            intro_text="introText",
            role="admin",
            subject="subject",
        )
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_send_weekly_digest(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.admin.v1.emails.with_raw_response.send_weekly_digest()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert email is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_send_weekly_digest(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.admin.v1.emails.with_streaming_response.send_weekly_digest() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = await response.parse()
            assert email is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.organizations import v2_search_params
from ...types.organizations.v2_search_response import V2SearchResponse
from ...types.organizations.v2_list_top_response import V2ListTopResponse
from ...types.organizations.v2_toggle_follow_response import V2ToggleFollowResponse
from ...types.organizations.v2_retrieve_by_id_response import V2RetrieveByIDResponse
from ...types.organizations.v2_retrieve_by_name_response import V2RetrieveByNameResponse

__all__ = ["V2Resource", "AsyncV2Resource"]


class V2Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> V2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V2ResourceWithStreamingResponse(self)

    def list_top(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2ListTopResponse:
        """
        Retrieve the top 20 organizations with images by paper count

        Source file:
        `api-server/src/controllers/organizations/v2/get-top-orgs.controller.ts`
        """
        return self._get(
            "/organizations/v2/top",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V2ListTopResponse,
        )

    def retrieve_by_id(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2RetrieveByIDResponse:
        """
        Retrieve an organization's basic information given its ID.

        Source file:
        `api-server/src/controllers/organizations/v2/get-organization-by-id.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/organizations/v2/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V2RetrieveByIDResponse,
        )

    def retrieve_by_name(
        self,
        name: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2RetrieveByNameResponse:
        """
        Retrieve an organization's basic information given it's name – casing does not
        matter (i.e. google and GOOGLE return the same results).

        Source file:
        `api-server/src/controllers/organizations/v2/get-organization-by-name.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not name:
            raise ValueError(f"Expected a non-empty value for `name` but received {name!r}")
        return self._get(
            f"/organizations/v2/by-name/{name}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V2RetrieveByNameResponse,
        )

    def search(
        self,
        *,
        q: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2SearchResponse:
        """
        Search organizations by name

        Source file: `api-server/src/controllers/organizations/v2/search.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/organizations/v2/search",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"q": q}, v2_search_params.V2SearchParams),
            ),
            cast_to=V2SearchResponse,
        )

    def toggle_follow(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2ToggleFollowResponse:
        """
        Toggle following an organization, affects the current user's profile

        Source file:
        `api-server/src/controllers/organizations/v2/toggle-follow-org.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._post(
            f"/organizations/v2/{id}/toggle",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V2ToggleFollowResponse,
        )


class AsyncV2Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncV2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV2ResourceWithStreamingResponse(self)

    async def list_top(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2ListTopResponse:
        """
        Retrieve the top 20 organizations with images by paper count

        Source file:
        `api-server/src/controllers/organizations/v2/get-top-orgs.controller.ts`
        """
        return await self._get(
            "/organizations/v2/top",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V2ListTopResponse,
        )

    async def retrieve_by_id(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2RetrieveByIDResponse:
        """
        Retrieve an organization's basic information given its ID.

        Source file:
        `api-server/src/controllers/organizations/v2/get-organization-by-id.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/organizations/v2/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V2RetrieveByIDResponse,
        )

    async def retrieve_by_name(
        self,
        name: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2RetrieveByNameResponse:
        """
        Retrieve an organization's basic information given it's name – casing does not
        matter (i.e. google and GOOGLE return the same results).

        Source file:
        `api-server/src/controllers/organizations/v2/get-organization-by-name.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not name:
            raise ValueError(f"Expected a non-empty value for `name` but received {name!r}")
        return await self._get(
            f"/organizations/v2/by-name/{name}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V2RetrieveByNameResponse,
        )

    async def search(
        self,
        *,
        q: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2SearchResponse:
        """
        Search organizations by name

        Source file: `api-server/src/controllers/organizations/v2/search.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/organizations/v2/search",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"q": q}, v2_search_params.V2SearchParams),
            ),
            cast_to=V2SearchResponse,
        )

    async def toggle_follow(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2ToggleFollowResponse:
        """
        Toggle following an organization, affects the current user's profile

        Source file:
        `api-server/src/controllers/organizations/v2/toggle-follow-org.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._post(
            f"/organizations/v2/{id}/toggle",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V2ToggleFollowResponse,
        )


class V2ResourceWithRawResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

        self.list_top = to_raw_response_wrapper(
            v2.list_top,
        )
        self.retrieve_by_id = to_raw_response_wrapper(
            v2.retrieve_by_id,
        )
        self.retrieve_by_name = to_raw_response_wrapper(
            v2.retrieve_by_name,
        )
        self.search = to_raw_response_wrapper(
            v2.search,
        )
        self.toggle_follow = to_raw_response_wrapper(
            v2.toggle_follow,
        )


class AsyncV2ResourceWithRawResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

        self.list_top = async_to_raw_response_wrapper(
            v2.list_top,
        )
        self.retrieve_by_id = async_to_raw_response_wrapper(
            v2.retrieve_by_id,
        )
        self.retrieve_by_name = async_to_raw_response_wrapper(
            v2.retrieve_by_name,
        )
        self.search = async_to_raw_response_wrapper(
            v2.search,
        )
        self.toggle_follow = async_to_raw_response_wrapper(
            v2.toggle_follow,
        )


class V2ResourceWithStreamingResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

        self.list_top = to_streamed_response_wrapper(
            v2.list_top,
        )
        self.retrieve_by_id = to_streamed_response_wrapper(
            v2.retrieve_by_id,
        )
        self.retrieve_by_name = to_streamed_response_wrapper(
            v2.retrieve_by_name,
        )
        self.search = to_streamed_response_wrapper(
            v2.search,
        )
        self.toggle_follow = to_streamed_response_wrapper(
            v2.toggle_follow,
        )


class AsyncV2ResourceWithStreamingResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

        self.list_top = async_to_streamed_response_wrapper(
            v2.list_top,
        )
        self.retrieve_by_id = async_to_streamed_response_wrapper(
            v2.retrieve_by_id,
        )
        self.retrieve_by_name = async_to_streamed_response_wrapper(
            v2.retrieve_by_name,
        )
        self.search = async_to_streamed_response_wrapper(
            v2.search,
        )
        self.toggle_follow = async_to_streamed_response_wrapper(
            v2.toggle_follow,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.mcp import v1_send_message_params
from ..._streaming import Stream, AsyncStream
from ..._base_client import make_request_options

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def establish_connection(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Stream[object]:
        """
        Establish SSE connection for server-to-client MCP messages

        Source file: `api-server/src/controllers/mcp/v1/get.controller.ts`
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return self._get(
            "/mcp/v1",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
            stream=True,
            stream_cls=Stream[object],
        )

    def send_message(
        self,
        *,
        body: object | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Send a message to the MCP server

        Source file: `api-server/src/controllers/mcp/v1/post.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/mcp/v1",
            body=maybe_transform(body, v1_send_message_params.V1SendMessageParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def terminate_session(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Terminate an MCP session

        Source file: `api-server/src/controllers/mcp/v1/delete.controller.ts`
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            "/mcp/v1",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def establish_connection(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncStream[object]:
        """
        Establish SSE connection for server-to-client MCP messages

        Source file: `api-server/src/controllers/mcp/v1/get.controller.ts`
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return await self._get(
            "/mcp/v1",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
            stream=True,
            stream_cls=AsyncStream[object],
        )

    async def send_message(
        self,
        *,
        body: object | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Send a message to the MCP server

        Source file: `api-server/src/controllers/mcp/v1/post.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/mcp/v1",
            body=await async_maybe_transform(body, v1_send_message_params.V1SendMessageParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def terminate_session(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Terminate an MCP session

        Source file: `api-server/src/controllers/mcp/v1/delete.controller.ts`
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            "/mcp/v1",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.establish_connection = to_raw_response_wrapper(
            v1.establish_connection,
        )
        self.send_message = to_raw_response_wrapper(
            v1.send_message,
        )
        self.terminate_session = to_raw_response_wrapper(
            v1.terminate_session,
        )


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.establish_connection = async_to_raw_response_wrapper(
            v1.establish_connection,
        )
        self.send_message = async_to_raw_response_wrapper(
            v1.send_message,
        )
        self.terminate_session = async_to_raw_response_wrapper(
            v1.terminate_session,
        )


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.establish_connection = to_streamed_response_wrapper(
            v1.establish_connection,
        )
        self.send_message = to_streamed_response_wrapper(
            v1.send_message,
        )
        self.terminate_session = to_streamed_response_wrapper(
            v1.terminate_session,
        )


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.establish_connection = async_to_streamed_response_wrapper(
            v1.establish_connection,
        )
        self.send_message = async_to_streamed_response_wrapper(
            v1.send_message,
        )
        self.terminate_session = async_to_streamed_response_wrapper(
            v1.terminate_session,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .seen import (
    SeenResource,
    AsyncSeenResource,
    SeenResourceWithRawResponse,
    AsyncSeenResourceWithRawResponse,
    SeenResourceWithStreamingResponse,
    AsyncSeenResourceWithStreamingResponse,
)
from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.briefs import v1_generate_speech_params
from ....types.briefs.v1_generate_speech_response import V1GenerateSpeechResponse

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def seen(self) -> SeenResource:
        return SeenResource(self._client)

    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def generate_speech(
        self,
        *,
        paper_group_id: str,
        text: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GenerateSpeechResponse:
        """Generates speech audio from brief summary text using ElevenLabs.

        Returns the
        CloudFront URL. Client should try the CDN URL first and only call this if it
        404s.

        Source file:
        `api-server/src/controllers/briefs/v1/generate-speech.controller.ts`

        Args:
          paper_group_id: Paper group ID for caching

          text: Text to convert to speech

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/briefs/v1/speech",
            body=maybe_transform(
                {
                    "paper_group_id": paper_group_id,
                    "text": text,
                },
                v1_generate_speech_params.V1GenerateSpeechParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GenerateSpeechResponse,
        )


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def seen(self) -> AsyncSeenResource:
        return AsyncSeenResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def generate_speech(
        self,
        *,
        paper_group_id: str,
        text: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GenerateSpeechResponse:
        """Generates speech audio from brief summary text using ElevenLabs.

        Returns the
        CloudFront URL. Client should try the CDN URL first and only call this if it
        404s.

        Source file:
        `api-server/src/controllers/briefs/v1/generate-speech.controller.ts`

        Args:
          paper_group_id: Paper group ID for caching

          text: Text to convert to speech

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/briefs/v1/speech",
            body=await async_maybe_transform(
                {
                    "paper_group_id": paper_group_id,
                    "text": text,
                },
                v1_generate_speech_params.V1GenerateSpeechParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GenerateSpeechResponse,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.generate_speech = to_raw_response_wrapper(
            v1.generate_speech,
        )

    @cached_property
    def seen(self) -> SeenResourceWithRawResponse:
        return SeenResourceWithRawResponse(self._v1.seen)


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.generate_speech = async_to_raw_response_wrapper(
            v1.generate_speech,
        )

    @cached_property
    def seen(self) -> AsyncSeenResourceWithRawResponse:
        return AsyncSeenResourceWithRawResponse(self._v1.seen)


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.generate_speech = to_streamed_response_wrapper(
            v1.generate_speech,
        )

    @cached_property
    def seen(self) -> SeenResourceWithStreamingResponse:
        return SeenResourceWithStreamingResponse(self._v1.seen)


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.generate_speech = async_to_streamed_response_wrapper(
            v1.generate_speech,
        )

    @cached_property
    def seen(self) -> AsyncSeenResourceWithStreamingResponse:
        return AsyncSeenResourceWithStreamingResponse(self._v1.seen)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v3_like_response import V3LikeResponse as V3LikeResponse
from .v2_comment_params import V2CommentParams as V2CommentParams
from .v3_comment_params import V3CommentParams as V3CommentParams
from .v2_comment_response import V2CommentResponse as V2CommentResponse
from .v3_comment_response import V3CommentResponse as V3CommentResponse
from .v3_process_ai_params import V3ProcessAIParams as V3ProcessAIParams
from .v3_retrieve_response import V3RetrieveResponse as V3RetrieveResponse
from .private_create_params import PrivateCreateParams as PrivateCreateParams
from .v3_delete_votes_params import V3DeleteVotesParams as V3DeleteVotesParams
from .v3_retrieve_all_params import V3RetrieveAllParams as V3RetrieveAllParams
from .private_create_response import PrivateCreateResponse as PrivateCreateResponse
from .v3_retrieve_feed_params import V3RetrieveFeedParams as V3RetrieveFeedParams
from .v3_implementation_params import V3ImplementationParams as V3ImplementationParams
from .v3_retrieve_all_response import V3RetrieveAllResponse as V3RetrieveAllResponse
from .v3_retrieve_feed_response import V3RetrieveFeedResponse as V3RetrieveFeedResponse
from .v3_implementation_response import V3ImplementationResponse as V3ImplementationResponse
from .ingest_ingest_latest_params import IngestIngestLatestParams as IngestIngestLatestParams
from .v3_process_countries_params import V3ProcessCountriesParams as V3ProcessCountriesParams
from .v3_process_full_text_params import V3ProcessFullTextParams as V3ProcessFullTextParams
from .v3_request_podcast_response import V3RequestPodcastResponse as V3RequestPodcastResponse
from .ingest_ingest_version_params import IngestIngestVersionParams as IngestIngestVersionParams
from .v3_retrieve_figures_response import V3RetrieveFiguresResponse as V3RetrieveFiguresResponse
from .v3_retrieve_metrics_response import V3RetrieveMetricsResponse as V3RetrieveMetricsResponse
from .v3_retrieve_preview_response import V3RetrievePreviewResponse as V3RetrievePreviewResponse
from .v3_retrieve_unrelated_params import V3RetrieveUnrelatedParams as V3RetrieveUnrelatedParams
from .ingest_ingest_latest_response import IngestIngestLatestResponse as IngestIngestLatestResponse
from .v3_retrieve_geo_trends_params import V3RetrieveGeoTrendsParams as V3RetrieveGeoTrendsParams
from .ingest_ingest_version_response import IngestIngestVersionResponse as IngestIngestVersionResponse
from .private_update_metadata_params import PrivateUpdateMetadataParams as PrivateUpdateMetadataParams
from .v3_retrieve_full_text_response import V3RetrieveFullTextResponse as V3RetrieveFullTextResponse
from .v3_retrieve_unrelated_response import V3RetrieveUnrelatedResponse as V3RetrieveUnrelatedResponse
from .v3_retrieve_geo_trends_response import V3RetrieveGeoTrendsResponse as V3RetrieveGeoTrendsResponse
from .v3_request_implementation_params import V3RequestImplementationParams as V3RequestImplementationParams
from .v3_kickoff_paper_countries_params import V3KickoffPaperCountriesParams as V3KickoffPaperCountriesParams
from .v3_kickoff_paper_full_text_params import V3KickoffPaperFullTextParams as V3KickoffPaperFullTextParams
from .v3_kickoff_x_mentions_sync_params import V3KickoffXMentionsSyncParams as V3KickoffXMentionsSyncParams
from .v3_retrieve_diverse_papers_params import V3RetrieveDiversePapersParams as V3RetrieveDiversePapersParams
from .v3_retrieve_similar_papers_params import V3RetrieveSimilarPapersParams as V3RetrieveSimilarPapersParams
from .v3_request_implementation_response import V3RequestImplementationResponse as V3RequestImplementationResponse
from .version_request_ai_overview_params import VersionRequestAIOverviewParams as VersionRequestAIOverviewParams
from .v3_retrieve_diverse_papers_response import V3RetrieveDiversePapersResponse as V3RetrieveDiversePapersResponse
from .v3_retrieve_similar_papers_response import V3RetrieveSimilarPapersResponse as V3RetrieveSimilarPapersResponse
from .v3_prune_embeddings_by_date_response import V3PruneEmbeddingsByDateResponse as V3PruneEmbeddingsByDateResponse
from .v3_retrieve_papers_by_country_params import V3RetrievePapersByCountryParams as V3RetrievePapersByCountryParams
from .version_request_ai_overview_response import VersionRequestAIOverviewResponse as VersionRequestAIOverviewResponse
from .v3_retrieve_papers_by_country_response import (
    V3RetrievePapersByCountryResponse as V3RetrievePapersByCountryResponse,
)
from .version_request_ai_translation_response import (
    VersionRequestAITranslationResponse as VersionRequestAITranslationResponse,
)
from .metadata_retrieve_latest_metadata_params import (
    MetadataRetrieveLatestMetadataParams as MetadataRetrieveLatestMetadataParams,
)
from .kickoff_daily_github_star_update_response import (
    KickoffDailyGitHubStarUpdateResponse as KickoffDailyGitHubStarUpdateResponse,
)
from .metadata_retrieve_version_metadata_params import (
    MetadataRetrieveVersionMetadataParams as MetadataRetrieveVersionMetadataParams,
)
from .metadata_retrieve_latest_metadata_response import (
    MetadataRetrieveLatestMetadataResponse as MetadataRetrieveLatestMetadataResponse,
)
from .metadata_retrieve_version_metadata_response import (
    MetadataRetrieveVersionMetadataResponse as MetadataRetrieveVersionMetadataResponse,
)
from .v3_kickoff_thumbnails_trending_papers_response import (
    V3KickoffThumbnailsTrendingPapersResponse as V3KickoffThumbnailsTrendingPapersResponse,
)
from .kickoff_daily_github_star_kickoff_daily_github_stars_response import (
    KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse as KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["ByUsernameGetUserResponse", "Avatar", "SemanticScholar", "Featured"]


class Avatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class SemanticScholar(BaseModel):
    id: str

    citation_count: Optional[float] = FieldInfo(alias="citationCount", default=None)

    external_ids: Optional[List[Optional[object]]] = FieldInfo(alias="externalIds", default=None)

    h_index: Optional[float] = FieldInfo(alias="hIndex", default=None)

    homepage: Optional[str] = None

    paper_count: Optional[float] = FieldInfo(alias="paperCount", default=None)


class Featured(BaseModel):
    event_id: Optional[str] = FieldInfo(alias="eventId", default=None)

    paper_version_id: Optional[str] = FieldInfo(alias="paperVersionId", default=None)

    type: Literal["video", "paper"]


class ByUsernameGetUserResponse(BaseModel):
    id: str

    avatar: Optional[List[Avatar]] = None

    biography: Optional[str] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    email: str

    first_login: bool = FieldInfo(alias="firstLogin")

    follower_count: float = FieldInfo(alias="followerCount")

    following_count: float = FieldInfo(alias="followingCount")

    following_topics_count: float = FieldInfo(alias="followingTopicsCount")

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    location: Optional[str] = None

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    semantic_scholar: Optional[SemanticScholar] = FieldInfo(alias="semanticScholar", default=None)

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)

    featured: Optional[List[Featured]] = None

    following_organizations: Optional[List[str]] = FieldInfo(alias="followingOrganizations", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.api_keys import v1_create_params, v1_create_impersonation_params
from ...types.api_keys.v1_list_response import V1ListResponse
from ...types.api_keys.v1_create_response import V1CreateResponse
from ...types.api_keys.v1_revoke_response import V1RevokeResponse
from ...types.api_keys.v1_create_impersonation_response import V1CreateImpersonationResponse

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        label: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1CreateResponse:
        """
        Create a new API key for the current user.

        Source file:
        `api-server/src/controllers/api-keys/v1/create-api-key.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api-keys/v1",
            body=maybe_transform({"label": label}, v1_create_params.V1CreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1CreateResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1ListResponse:
        """
        List API keys for the current user.

        Source file: `api-server/src/controllers/api-keys/v1/get-api-keys.controller.ts`
        """
        return self._get(
            "/api-keys/v1",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1ListResponse,
        )

    def create_impersonation(
        self,
        *,
        user: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1CreateImpersonationResponse:
        """
        Create a new API key for the current user.

        Source file:
        `api-server/src/controllers/api-keys/v1/create-impersonation-api-key.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api-keys/v1/impersonate",
            body=maybe_transform({"user": user}, v1_create_impersonation_params.V1CreateImpersonationParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1CreateImpersonationResponse,
        )

    def revoke(
        self,
        api_key_id: Union[str, Literal["own"]],
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1RevokeResponse:
        """Revoke an API key for the authenticated user.

        No-op if already revoked.

        Source file:
        `api-server/src/controllers/api-keys/v1/revoke-api-key.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            f"/api-keys/v1/{api_key_id}/revoke",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1RevokeResponse,
        )


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        label: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1CreateResponse:
        """
        Create a new API key for the current user.

        Source file:
        `api-server/src/controllers/api-keys/v1/create-api-key.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api-keys/v1",
            body=await async_maybe_transform({"label": label}, v1_create_params.V1CreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1CreateResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1ListResponse:
        """
        List API keys for the current user.

        Source file: `api-server/src/controllers/api-keys/v1/get-api-keys.controller.ts`
        """
        return await self._get(
            "/api-keys/v1",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1ListResponse,
        )

    async def create_impersonation(
        self,
        *,
        user: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1CreateImpersonationResponse:
        """
        Create a new API key for the current user.

        Source file:
        `api-server/src/controllers/api-keys/v1/create-impersonation-api-key.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api-keys/v1/impersonate",
            body=await async_maybe_transform(
                {"user": user}, v1_create_impersonation_params.V1CreateImpersonationParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1CreateImpersonationResponse,
        )

    async def revoke(
        self,
        api_key_id: Union[str, Literal["own"]],
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1RevokeResponse:
        """Revoke an API key for the authenticated user.

        No-op if already revoked.

        Source file:
        `api-server/src/controllers/api-keys/v1/revoke-api-key.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            f"/api-keys/v1/{api_key_id}/revoke",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1RevokeResponse,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.create = to_raw_response_wrapper(
            v1.create,
        )
        self.list = to_raw_response_wrapper(
            v1.list,
        )
        self.create_impersonation = to_raw_response_wrapper(
            v1.create_impersonation,
        )
        self.revoke = to_raw_response_wrapper(
            v1.revoke,
        )


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.create = async_to_raw_response_wrapper(
            v1.create,
        )
        self.list = async_to_raw_response_wrapper(
            v1.list,
        )
        self.create_impersonation = async_to_raw_response_wrapper(
            v1.create_impersonation,
        )
        self.revoke = async_to_raw_response_wrapper(
            v1.revoke,
        )


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.create = to_streamed_response_wrapper(
            v1.create,
        )
        self.list = to_streamed_response_wrapper(
            v1.list,
        )
        self.create_impersonation = to_streamed_response_wrapper(
            v1.create_impersonation,
        )
        self.revoke = to_streamed_response_wrapper(
            v1.revoke,
        )


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.create = async_to_streamed_response_wrapper(
            v1.create,
        )
        self.list = async_to_streamed_response_wrapper(
            v1.list,
        )
        self.create_impersonation = async_to_streamed_response_wrapper(
            v1.create_impersonation,
        )
        self.revoke = async_to_streamed_response_wrapper(
            v1.revoke,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.papers import (
    MetadataRetrieveLatestMetadataResponse,
    MetadataRetrieveVersionMetadataResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMetadata:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_latest_metadata(self, client: AlphaxivCat) -> None:
        metadata = client.papers.metadata.retrieve_latest_metadata(
            upid="x",
        )
        assert_matches_type(MetadataRetrieveLatestMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_latest_metadata_with_all_params(self, client: AlphaxivCat) -> None:
        metadata = client.papers.metadata.retrieve_latest_metadata(
            upid="x",
            prevent_tracking="preventTracking",
        )
        assert_matches_type(MetadataRetrieveLatestMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_latest_metadata(self, client: AlphaxivCat) -> None:
        response = client.papers.metadata.with_raw_response.retrieve_latest_metadata(
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = response.parse()
        assert_matches_type(MetadataRetrieveLatestMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_latest_metadata(self, client: AlphaxivCat) -> None:
        with client.papers.metadata.with_streaming_response.retrieve_latest_metadata(
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = response.parse()
            assert_matches_type(MetadataRetrieveLatestMetadataResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve_latest_metadata(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            client.papers.metadata.with_raw_response.retrieve_latest_metadata(
                upid="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_version_metadata(self, client: AlphaxivCat) -> None:
        metadata = client.papers.metadata.retrieve_version_metadata(
            version_order="x",
            upid="x",
        )
        assert_matches_type(MetadataRetrieveVersionMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_version_metadata_with_all_params(self, client: AlphaxivCat) -> None:
        metadata = client.papers.metadata.retrieve_version_metadata(
            version_order="x",
            upid="x",
            prevent_tracking="preventTracking",
        )
        assert_matches_type(MetadataRetrieveVersionMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_version_metadata(self, client: AlphaxivCat) -> None:
        response = client.papers.metadata.with_raw_response.retrieve_version_metadata(
            version_order="x",
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = response.parse()
        assert_matches_type(MetadataRetrieveVersionMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_version_metadata(self, client: AlphaxivCat) -> None:
        with client.papers.metadata.with_streaming_response.retrieve_version_metadata(
            version_order="x",
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = response.parse()
            assert_matches_type(MetadataRetrieveVersionMetadataResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve_version_metadata(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            client.papers.metadata.with_raw_response.retrieve_version_metadata(
                version_order="x",
                upid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `version_order` but received ''"):
            client.papers.metadata.with_raw_response.retrieve_version_metadata(
                version_order="",
                upid="x",
            )


class TestAsyncMetadata:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_latest_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        metadata = await async_client.papers.metadata.retrieve_latest_metadata(
            upid="x",
        )
        assert_matches_type(MetadataRetrieveLatestMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_latest_metadata_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        metadata = await async_client.papers.metadata.retrieve_latest_metadata(
            upid="x",
            prevent_tracking="preventTracking",
        )
        assert_matches_type(MetadataRetrieveLatestMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_latest_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.metadata.with_raw_response.retrieve_latest_metadata(
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = await response.parse()
        assert_matches_type(MetadataRetrieveLatestMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_latest_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.metadata.with_streaming_response.retrieve_latest_metadata(
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = await response.parse()
            assert_matches_type(MetadataRetrieveLatestMetadataResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve_latest_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            await async_client.papers.metadata.with_raw_response.retrieve_latest_metadata(
                upid="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_version_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        metadata = await async_client.papers.metadata.retrieve_version_metadata(
            version_order="x",
            upid="x",
        )
        assert_matches_type(MetadataRetrieveVersionMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_version_metadata_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        metadata = await async_client.papers.metadata.retrieve_version_metadata(
            version_order="x",
            upid="x",
            prevent_tracking="preventTracking",
        )
        assert_matches_type(MetadataRetrieveVersionMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_version_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.metadata.with_raw_response.retrieve_version_metadata(
            version_order="x",
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = await response.parse()
        assert_matches_type(MetadataRetrieveVersionMetadataResponse, metadata, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_version_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.metadata.with_streaming_response.retrieve_version_metadata(
            version_order="x",
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = await response.parse()
            assert_matches_type(MetadataRetrieveVersionMetadataResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve_version_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            await async_client.papers.metadata.with_raw_response.retrieve_version_metadata(
                version_order="x",
                upid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `version_order` but received ''"):
            await async_client.papers.metadata.with_raw_response.retrieve_version_metadata(
                version_order="",
                upid="x",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions
from typing_extensions import Literal

import httpx

from ..types import (
    email_process_bounced_email_params,
    email_capture_bounced_emails_params,
    email_process_comment_update_params,
    email_process_general_update_params,
    email_capture_resend_bounced_email_params,
)
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.email_process_bounced_email_response import EmailProcessBouncedEmailResponse
from ..types.email_capture_bounced_emails_response import EmailCaptureBouncedEmailsResponse
from ..types.email_kickoff_comment_update_response import EmailKickoffCommentUpdateResponse
from ..types.email_kickoff_general_update_response import EmailKickoffGeneralUpdateResponse
from ..types.email_process_comment_update_response import EmailProcessCommentUpdateResponse
from ..types.email_process_general_update_response import EmailProcessGeneralUpdateResponse
from ..types.email_capture_resend_bounced_email_response import EmailCaptureResendBouncedEmailResponse

__all__ = ["EmailsResource", "AsyncEmailsResource"]


class EmailsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EmailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return EmailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EmailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return EmailsResourceWithStreamingResponse(self)

    def capture_bounced_emails(
        self,
        *,
        message: str,
        type: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailCaptureBouncedEmailsResponse:
        """
        Receives bounce notifications from AWS SES via SNS

        Source file:
        `api-server/src/controllers/v1/emails/capture-bounced-emails.controller.ts`

        Args:
          message: Stringified JSON message containing bounce/complaint data

          type: SNS notification type

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/emails/capture-bounced-emails",
            body=maybe_transform(
                {
                    "message": message,
                    "type": type,
                },
                email_capture_bounced_emails_params.EmailCaptureBouncedEmailsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailCaptureBouncedEmailsResponse,
        )

    def capture_resend_bounced_email(
        self,
        *,
        data: email_capture_resend_bounced_email_params.Data,
        type: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailCaptureResendBouncedEmailResponse:
        """
        Receives bounce notifications from Resend

        Source file:
        `api-server/src/controllers/v1/emails/capture-resend-bounced-emails.controller.ts`

        Args:
          data: Event data containing bounced emails

          type: Event type from Resend

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/emails/capture-resend-bounced-email",
            body=maybe_transform(
                {
                    "data": data,
                    "type": type,
                },
                email_capture_resend_bounced_email_params.EmailCaptureResendBouncedEmailParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailCaptureResendBouncedEmailResponse,
        )

    def kickoff_comment_update(
        self,
        custom: Literal["true", "false"],
        *,
        role: str,
        window: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailKickoffCommentUpdateResponse:
        """
        Kicks off a background job to send comment digest emails to users

        Source file:
        `api-server/src/controllers/v1/emails/kickoff-comment-updates.controller.ts`

        Args:
          role: User role to filter by

          window: Time window in hours

          custom: Whether to use custom digest

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not role:
            raise ValueError(f"Expected a non-empty value for `role` but received {role!r}")
        if not window:
            raise ValueError(f"Expected a non-empty value for `window` but received {window!r}")
        if not custom:
            raise ValueError(f"Expected a non-empty value for `custom` but received {custom!r}")
        return self._post(
            f"/v1/emails/kickoff-comment-update/{role}/{window}/{custom}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailKickoffCommentUpdateResponse,
        )

    def kickoff_general_update(
        self,
        role: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailKickoffGeneralUpdateResponse:
        """
        Kicks off a background job to send general digest emails to users

        Source file:
        `api-server/src/controllers/v1/emails/kickoff-general-updates.controller.ts`

        Args:
          role: User role to filter by

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not role:
            raise ValueError(f"Expected a non-empty value for `role` but received {role!r}")
        return self._post(
            f"/v1/emails/kickoff-general-update/{role}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailKickoffGeneralUpdateResponse,
        )

    @typing_extensions.deprecated("deprecated")
    def process_bounced_email(
        self,
        *,
        email: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailProcessBouncedEmailResponse:
        """
        Process a bounced email and update user preferences

        Source file:
        `api-server/src/controllers/v1/emails/process-bounced-email.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/emails/process-bounced-email",
            body=maybe_transform({"email": email}, email_process_bounced_email_params.EmailProcessBouncedEmailParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailProcessBouncedEmailResponse,
        )

    @typing_extensions.deprecated("deprecated")
    def process_comment_update(
        self,
        *,
        user_id: str,
        custom_content: email_process_comment_update_params.CustomContent | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailProcessCommentUpdateResponse:
        """
        Process comment digest email for a user

        Source file:
        `api-server/src/controllers/v1/emails/process-user-comment-update.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/emails/process-comment-update",
            body=maybe_transform(
                {
                    "user_id": user_id,
                    "custom_content": custom_content,
                },
                email_process_comment_update_params.EmailProcessCommentUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailProcessCommentUpdateResponse,
        )

    @typing_extensions.deprecated("deprecated")
    def process_general_update(
        self,
        *,
        user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailProcessGeneralUpdateResponse:
        """
        Process general digest email for a user

        Source file:
        `api-server/src/controllers/v1/emails/process-user-general-update.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/emails/process-general-update",
            body=maybe_transform(
                {"user_id": user_id}, email_process_general_update_params.EmailProcessGeneralUpdateParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailProcessGeneralUpdateResponse,
        )


class AsyncEmailsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEmailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEmailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEmailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncEmailsResourceWithStreamingResponse(self)

    async def capture_bounced_emails(
        self,
        *,
        message: str,
        type: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailCaptureBouncedEmailsResponse:
        """
        Receives bounce notifications from AWS SES via SNS

        Source file:
        `api-server/src/controllers/v1/emails/capture-bounced-emails.controller.ts`

        Args:
          message: Stringified JSON message containing bounce/complaint data

          type: SNS notification type

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/emails/capture-bounced-emails",
            body=await async_maybe_transform(
                {
                    "message": message,
                    "type": type,
                },
                email_capture_bounced_emails_params.EmailCaptureBouncedEmailsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailCaptureBouncedEmailsResponse,
        )

    async def capture_resend_bounced_email(
        self,
        *,
        data: email_capture_resend_bounced_email_params.Data,
        type: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailCaptureResendBouncedEmailResponse:
        """
        Receives bounce notifications from Resend

        Source file:
        `api-server/src/controllers/v1/emails/capture-resend-bounced-emails.controller.ts`

        Args:
          data: Event data containing bounced emails

          type: Event type from Resend

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/emails/capture-resend-bounced-email",
            body=await async_maybe_transform(
                {
                    "data": data,
                    "type": type,
                },
                email_capture_resend_bounced_email_params.EmailCaptureResendBouncedEmailParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailCaptureResendBouncedEmailResponse,
        )

    async def kickoff_comment_update(
        self,
        custom: Literal["true", "false"],
        *,
        role: str,
        window: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailKickoffCommentUpdateResponse:
        """
        Kicks off a background job to send comment digest emails to users

        Source file:
        `api-server/src/controllers/v1/emails/kickoff-comment-updates.controller.ts`

        Args:
          role: User role to filter by

          window: Time window in hours

          custom: Whether to use custom digest

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not role:
            raise ValueError(f"Expected a non-empty value for `role` but received {role!r}")
        if not window:
            raise ValueError(f"Expected a non-empty value for `window` but received {window!r}")
        if not custom:
            raise ValueError(f"Expected a non-empty value for `custom` but received {custom!r}")
        return await self._post(
            f"/v1/emails/kickoff-comment-update/{role}/{window}/{custom}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailKickoffCommentUpdateResponse,
        )

    async def kickoff_general_update(
        self,
        role: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailKickoffGeneralUpdateResponse:
        """
        Kicks off a background job to send general digest emails to users

        Source file:
        `api-server/src/controllers/v1/emails/kickoff-general-updates.controller.ts`

        Args:
          role: User role to filter by

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not role:
            raise ValueError(f"Expected a non-empty value for `role` but received {role!r}")
        return await self._post(
            f"/v1/emails/kickoff-general-update/{role}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailKickoffGeneralUpdateResponse,
        )

    @typing_extensions.deprecated("deprecated")
    async def process_bounced_email(
        self,
        *,
        email: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailProcessBouncedEmailResponse:
        """
        Process a bounced email and update user preferences

        Source file:
        `api-server/src/controllers/v1/emails/process-bounced-email.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/emails/process-bounced-email",
            body=await async_maybe_transform(
                {"email": email}, email_process_bounced_email_params.EmailProcessBouncedEmailParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailProcessBouncedEmailResponse,
        )

    @typing_extensions.deprecated("deprecated")
    async def process_comment_update(
        self,
        *,
        user_id: str,
        custom_content: email_process_comment_update_params.CustomContent | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailProcessCommentUpdateResponse:
        """
        Process comment digest email for a user

        Source file:
        `api-server/src/controllers/v1/emails/process-user-comment-update.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/emails/process-comment-update",
            body=await async_maybe_transform(
                {
                    "user_id": user_id,
                    "custom_content": custom_content,
                },
                email_process_comment_update_params.EmailProcessCommentUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailProcessCommentUpdateResponse,
        )

    @typing_extensions.deprecated("deprecated")
    async def process_general_update(
        self,
        *,
        user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailProcessGeneralUpdateResponse:
        """
        Process general digest email for a user

        Source file:
        `api-server/src/controllers/v1/emails/process-user-general-update.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/emails/process-general-update",
            body=await async_maybe_transform(
                {"user_id": user_id}, email_process_general_update_params.EmailProcessGeneralUpdateParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailProcessGeneralUpdateResponse,
        )


class EmailsResourceWithRawResponse:
    def __init__(self, emails: EmailsResource) -> None:
        self._emails = emails

        self.capture_bounced_emails = to_raw_response_wrapper(
            emails.capture_bounced_emails,
        )
        self.capture_resend_bounced_email = to_raw_response_wrapper(
            emails.capture_resend_bounced_email,
        )
        self.kickoff_comment_update = to_raw_response_wrapper(
            emails.kickoff_comment_update,
        )
        self.kickoff_general_update = to_raw_response_wrapper(
            emails.kickoff_general_update,
        )
        self.process_bounced_email = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                emails.process_bounced_email,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_comment_update = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                emails.process_comment_update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_general_update = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                emails.process_general_update,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncEmailsResourceWithRawResponse:
    def __init__(self, emails: AsyncEmailsResource) -> None:
        self._emails = emails

        self.capture_bounced_emails = async_to_raw_response_wrapper(
            emails.capture_bounced_emails,
        )
        self.capture_resend_bounced_email = async_to_raw_response_wrapper(
            emails.capture_resend_bounced_email,
        )
        self.kickoff_comment_update = async_to_raw_response_wrapper(
            emails.kickoff_comment_update,
        )
        self.kickoff_general_update = async_to_raw_response_wrapper(
            emails.kickoff_general_update,
        )
        self.process_bounced_email = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                emails.process_bounced_email,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_comment_update = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                emails.process_comment_update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_general_update = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                emails.process_general_update,  # pyright: ignore[reportDeprecated],
            )
        )


class EmailsResourceWithStreamingResponse:
    def __init__(self, emails: EmailsResource) -> None:
        self._emails = emails

        self.capture_bounced_emails = to_streamed_response_wrapper(
            emails.capture_bounced_emails,
        )
        self.capture_resend_bounced_email = to_streamed_response_wrapper(
            emails.capture_resend_bounced_email,
        )
        self.kickoff_comment_update = to_streamed_response_wrapper(
            emails.kickoff_comment_update,
        )
        self.kickoff_general_update = to_streamed_response_wrapper(
            emails.kickoff_general_update,
        )
        self.process_bounced_email = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                emails.process_bounced_email,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_comment_update = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                emails.process_comment_update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_general_update = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                emails.process_general_update,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncEmailsResourceWithStreamingResponse:
    def __init__(self, emails: AsyncEmailsResource) -> None:
        self._emails = emails

        self.capture_bounced_emails = async_to_streamed_response_wrapper(
            emails.capture_bounced_emails,
        )
        self.capture_resend_bounced_email = async_to_streamed_response_wrapper(
            emails.capture_resend_bounced_email,
        )
        self.kickoff_comment_update = async_to_streamed_response_wrapper(
            emails.kickoff_comment_update,
        )
        self.kickoff_general_update = async_to_streamed_response_wrapper(
            emails.kickoff_general_update,
        )
        self.process_bounced_email = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                emails.process_bounced_email,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_comment_update = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                emails.process_comment_update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_general_update = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                emails.process_general_update,  # pyright: ignore[reportDeprecated],
            )
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["V4SubscribeParams", "Subscription", "SubscriptionKeys"]


class V4SubscribeParams(TypedDict, total=False):
    subscription: Required[Subscription]


class SubscriptionKeys(TypedDict, total=False):
    auth: Required[str]

    p256dh: Required[str]


class Subscription(TypedDict, total=False):
    endpoint: Required[str]

    keys: Required[SubscriptionKeys]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V1SetEmailParams"]


class V1SetEmailParams(TypedDict, total=False):
    local_part: Required[Annotated[str, PropertyInfo(alias="localPart")]]
    """Institutional email local-part"""

    verify_account_email: Required[Annotated[bool, PropertyInfo(alias="verifyAccountEmail")]]
    """
    Send verification code to the user's primary email instead of the institutional
    email. Admin only.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions
from typing import Optional

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.analytics import (
    paper_view_count_kickoff_job_params,
    paper_view_count_process_job_params,
    paper_view_count_ingest_event_params,
)
from ...types.analytics.paper_view_count_kickoff_job_response import PaperViewCountKickoffJobResponse
from ...types.analytics.paper_view_count_process_job_response import PaperViewCountProcessJobResponse
from ...types.analytics.paper_view_count_ingest_event_response import PaperViewCountIngestEventResponse

__all__ = ["PaperViewCountResource", "AsyncPaperViewCountResource"]


class PaperViewCountResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PaperViewCountResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return PaperViewCountResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PaperViewCountResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return PaperViewCountResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    def ingest_event(
        self,
        *,
        paper_id: str,
        created_at: str | Omit = omit,
        user_id: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperViewCountIngestEventResponse:
        """
        Track a paper view event for analytics

        Source file:
        `api-server/src/controllers/v1/analytics/ingest-paper-view-count-event.controller.ts`

        Args:
          paper_id: Paper ID to track view for

          created_at: Optional timestamp for the view event

          user_id: Optional user ID who viewed the paper

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/analytics/paper-view-count/ingest",
            body=maybe_transform(
                {
                    "paper_id": paper_id,
                    "created_at": created_at,
                    "user_id": user_id,
                },
                paper_view_count_ingest_event_params.PaperViewCountIngestEventParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperViewCountIngestEventResponse,
        )

    def kickoff_job(
        self,
        *,
        type: str,
        like: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperViewCountKickoffJobResponse:
        """
        Kicks off a background job to aggregate paper view counts

        Source file:
        `api-server/src/controllers/v1/analytics/kickoff-paper-view-count-aggregation-job.controller.ts`

        Args:
          type: Time period filter: 'all' or number of days

          like: Optional filter for likes

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/analytics/paper-view-count/kickoff-job",
            body=maybe_transform(
                {
                    "type": type,
                    "like": like,
                },
                paper_view_count_kickoff_job_params.PaperViewCountKickoffJobParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperViewCountKickoffJobResponse,
        )

    @typing_extensions.deprecated("deprecated")
    def process_job(
        self,
        *,
        paper_id: str,
        publication_date: str,
        like: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperViewCountProcessJobResponse:
        """
        Process view count aggregation for a specific paper

        Source file:
        `api-server/src/controllers/v1/analytics/process-paper-view-count-aggregation-job.controller.ts`

        Args:
          paper_id: Paper ID to process view counts for

          publication_date: Publication date for age decay calculation

          like: Whether to add noise to votes

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/analytics/paper-view-count/process-job",
            body=maybe_transform(
                {
                    "paper_id": paper_id,
                    "publication_date": publication_date,
                    "like": like,
                },
                paper_view_count_process_job_params.PaperViewCountProcessJobParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperViewCountProcessJobResponse,
        )


class AsyncPaperViewCountResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPaperViewCountResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPaperViewCountResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPaperViewCountResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncPaperViewCountResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    async def ingest_event(
        self,
        *,
        paper_id: str,
        created_at: str | Omit = omit,
        user_id: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperViewCountIngestEventResponse:
        """
        Track a paper view event for analytics

        Source file:
        `api-server/src/controllers/v1/analytics/ingest-paper-view-count-event.controller.ts`

        Args:
          paper_id: Paper ID to track view for

          created_at: Optional timestamp for the view event

          user_id: Optional user ID who viewed the paper

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/analytics/paper-view-count/ingest",
            body=await async_maybe_transform(
                {
                    "paper_id": paper_id,
                    "created_at": created_at,
                    "user_id": user_id,
                },
                paper_view_count_ingest_event_params.PaperViewCountIngestEventParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperViewCountIngestEventResponse,
        )

    async def kickoff_job(
        self,
        *,
        type: str,
        like: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperViewCountKickoffJobResponse:
        """
        Kicks off a background job to aggregate paper view counts

        Source file:
        `api-server/src/controllers/v1/analytics/kickoff-paper-view-count-aggregation-job.controller.ts`

        Args:
          type: Time period filter: 'all' or number of days

          like: Optional filter for likes

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/analytics/paper-view-count/kickoff-job",
            body=await async_maybe_transform(
                {
                    "type": type,
                    "like": like,
                },
                paper_view_count_kickoff_job_params.PaperViewCountKickoffJobParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperViewCountKickoffJobResponse,
        )

    @typing_extensions.deprecated("deprecated")
    async def process_job(
        self,
        *,
        paper_id: str,
        publication_date: str,
        like: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperViewCountProcessJobResponse:
        """
        Process view count aggregation for a specific paper

        Source file:
        `api-server/src/controllers/v1/analytics/process-paper-view-count-aggregation-job.controller.ts`

        Args:
          paper_id: Paper ID to process view counts for

          publication_date: Publication date for age decay calculation

          like: Whether to add noise to votes

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/analytics/paper-view-count/process-job",
            body=await async_maybe_transform(
                {
                    "paper_id": paper_id,
                    "publication_date": publication_date,
                    "like": like,
                },
                paper_view_count_process_job_params.PaperViewCountProcessJobParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperViewCountProcessJobResponse,
        )


class PaperViewCountResourceWithRawResponse:
    def __init__(self, paper_view_count: PaperViewCountResource) -> None:
        self._paper_view_count = paper_view_count

        self.ingest_event = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                paper_view_count.ingest_event,  # pyright: ignore[reportDeprecated],
            )
        )
        self.kickoff_job = to_raw_response_wrapper(
            paper_view_count.kickoff_job,
        )
        self.process_job = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                paper_view_count.process_job,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncPaperViewCountResourceWithRawResponse:
    def __init__(self, paper_view_count: AsyncPaperViewCountResource) -> None:
        self._paper_view_count = paper_view_count

        self.ingest_event = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                paper_view_count.ingest_event,  # pyright: ignore[reportDeprecated],
            )
        )
        self.kickoff_job = async_to_raw_response_wrapper(
            paper_view_count.kickoff_job,
        )
        self.process_job = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                paper_view_count.process_job,  # pyright: ignore[reportDeprecated],
            )
        )


class PaperViewCountResourceWithStreamingResponse:
    def __init__(self, paper_view_count: PaperViewCountResource) -> None:
        self._paper_view_count = paper_view_count

        self.ingest_event = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                paper_view_count.ingest_event,  # pyright: ignore[reportDeprecated],
            )
        )
        self.kickoff_job = to_streamed_response_wrapper(
            paper_view_count.kickoff_job,
        )
        self.process_job = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                paper_view_count.process_job,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncPaperViewCountResourceWithStreamingResponse:
    def __init__(self, paper_view_count: AsyncPaperViewCountResource) -> None:
        self._paper_view_count = paper_view_count

        self.ingest_event = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                paper_view_count.ingest_event,  # pyright: ignore[reportDeprecated],
            )
        )
        self.kickoff_job = async_to_streamed_response_wrapper(
            paper_view_count.kickoff_job,
        )
        self.process_job = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                paper_view_count.process_job,  # pyright: ignore[reportDeprecated],
            )
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from typing_extensions import Literal, TypeAlias

from ..._models import BaseModel

__all__ = [
    "V3GetFeaturedActivityResponse",
    "V3GetFeaturedActivityResponseItem",
    "V3GetFeaturedActivityResponseItemUnionMember0",
    "V3GetFeaturedActivityResponseItemUnionMember0Data",
    "V3GetFeaturedActivityResponseItemUnionMember1",
    "V3GetFeaturedActivityResponseItemUnionMember1Data",
]


class V3GetFeaturedActivityResponseItemUnionMember0Data(BaseModel):
    id: str

    date: str

    link: Optional[str] = None

    organization: Optional[str] = None

    recording: Optional[str] = None

    speaker: Optional[str] = None

    title: str


class V3GetFeaturedActivityResponseItemUnionMember0(BaseModel):
    data: V3GetFeaturedActivityResponseItemUnionMember0Data

    type: Literal["video"]


class V3GetFeaturedActivityResponseItemUnionMember1Data(BaseModel):
    abstract: Optional[str] = None

    publication_date: str

    title: str

    universal_paper_id: str


class V3GetFeaturedActivityResponseItemUnionMember1(BaseModel):
    data: V3GetFeaturedActivityResponseItemUnionMember1Data

    type: Literal["paper"]


V3GetFeaturedActivityResponseItem: TypeAlias = Union[
    V3GetFeaturedActivityResponseItemUnionMember0, V3GetFeaturedActivityResponseItemUnionMember1
]

V3GetFeaturedActivityResponse: TypeAlias = List[V3GetFeaturedActivityResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_sync_response import V1SyncResponse as V1SyncResponse
from .v1_connect_params import V1ConnectParams as V1ConnectParams
from .v1_resync_response import V1ResyncResponse as V1ResyncResponse
from .v1_connect_response import V1ConnectResponse as V1ConnectResponse
from .v1_set_email_params import V1SetEmailParams as V1SetEmailParams
from .v1_get_report_response import V1GetReportResponse as V1GetReportResponse
from .v1_get_status_response import V1GetStatusResponse as V1GetStatusResponse
from .v1_verify_email_params import V1VerifyEmailParams as V1VerifyEmailParams
from .v1_verify_email_response import V1VerifyEmailResponse as V1VerifyEmailResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .google_scholar import (
    GoogleScholarResource,
    AsyncGoogleScholarResource,
    GoogleScholarResourceWithRawResponse,
    AsyncGoogleScholarResourceWithRawResponse,
    GoogleScholarResourceWithStreamingResponse,
    AsyncGoogleScholarResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "GoogleScholarResource",
    "AsyncGoogleScholarResource",
    "GoogleScholarResourceWithRawResponse",
    "AsyncGoogleScholarResourceWithRawResponse",
    "GoogleScholarResourceWithStreamingResponse",
    "AsyncGoogleScholarResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["EmailSendMonthlyDigestParams"]


class EmailSendMonthlyDigestParams(TypedDict, total=False):
    role: Literal["admin", "user"]
    """Filter by user role"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.users.v3.citation_get_graph_response import CitationGetGraphResponse
from ....types.users.v3.citation_get_summary_response import CitationGetSummaryResponse

__all__ = ["CitationsResource", "AsyncCitationsResource"]


class CitationsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CitationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return CitationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CitationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return CitationsResourceWithStreamingResponse(self)

    def get_graph(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CitationGetGraphResponse:
        """
        Retrieve citation counts by year for a user

        Source file:
        `api-server/src/controllers/users/v3/get-citation-graph.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/users/v3/{id}/citations/graph",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CitationGetGraphResponse,
        )

    def get_summary(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CitationGetSummaryResponse:
        """
        Retrieve aggregated citation metrics for a user

        Source file:
        `api-server/src/controllers/users/v3/get-citation-summary.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/users/v3/{id}/citations/summary",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CitationGetSummaryResponse,
        )


class AsyncCitationsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCitationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCitationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCitationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncCitationsResourceWithStreamingResponse(self)

    async def get_graph(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CitationGetGraphResponse:
        """
        Retrieve citation counts by year for a user

        Source file:
        `api-server/src/controllers/users/v3/get-citation-graph.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/users/v3/{id}/citations/graph",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CitationGetGraphResponse,
        )

    async def get_summary(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CitationGetSummaryResponse:
        """
        Retrieve aggregated citation metrics for a user

        Source file:
        `api-server/src/controllers/users/v3/get-citation-summary.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/users/v3/{id}/citations/summary",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CitationGetSummaryResponse,
        )


class CitationsResourceWithRawResponse:
    def __init__(self, citations: CitationsResource) -> None:
        self._citations = citations

        self.get_graph = to_raw_response_wrapper(
            citations.get_graph,
        )
        self.get_summary = to_raw_response_wrapper(
            citations.get_summary,
        )


class AsyncCitationsResourceWithRawResponse:
    def __init__(self, citations: AsyncCitationsResource) -> None:
        self._citations = citations

        self.get_graph = async_to_raw_response_wrapper(
            citations.get_graph,
        )
        self.get_summary = async_to_raw_response_wrapper(
            citations.get_summary,
        )


class CitationsResourceWithStreamingResponse:
    def __init__(self, citations: CitationsResource) -> None:
        self._citations = citations

        self.get_graph = to_streamed_response_wrapper(
            citations.get_graph,
        )
        self.get_summary = to_streamed_response_wrapper(
            citations.get_summary,
        )


class AsyncCitationsResourceWithStreamingResponse:
    def __init__(self, citations: AsyncCitationsResource) -> None:
        self._citations = citations

        self.get_graph = async_to_streamed_response_wrapper(
            citations.get_graph,
        )
        self.get_summary = async_to_streamed_response_wrapper(
            citations.get_summary,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["V2ToggleFollowResponse"]


class V2ToggleFollowResponse(BaseModel):
    following: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from .messages import (
    MessagesResource,
    AsyncMessagesResource,
    MessagesResourceWithRawResponse,
    AsyncMessagesResourceWithRawResponse,
    MessagesResourceWithStreamingResponse,
    AsyncMessagesResourceWithStreamingResponse,
)

__all__ = [
    "MessagesResource",
    "AsyncMessagesResource",
    "MessagesResourceWithRawResponse",
    "AsyncMessagesResourceWithRawResponse",
    "MessagesResourceWithStreamingResponse",
    "AsyncMessagesResourceWithStreamingResponse",
    "V2Resource",
    "AsyncV2Resource",
    "V2ResourceWithRawResponse",
    "AsyncV2ResourceWithRawResponse",
    "V2ResourceWithStreamingResponse",
    "AsyncV2ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["PaperViewCountIngestEventResponse", "Data"]


class Data(BaseModel):
    ingested_paper: str = FieldInfo(alias="ingestedPaper")


class PaperViewCountIngestEventResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .message_list_response import MessageListResponse as MessageListResponse
from .message_set_feedback_params import MessageSetFeedbackParams as MessageSetFeedbackParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["PaperEmailAuthorParams"]


class PaperEmailAuthorParams(TypedDict, total=False):
    author_individual_email: Required[Annotated[str, PropertyInfo(alias="authorIndividualEmail")]]

    email_author_name: Required[Annotated[str, PropertyInfo(alias="emailAuthorName")]]

    paper_name: Required[Annotated[str, PropertyInfo(alias="paperName")]]

    type: Required[Literal["comment", "trending"]]

    ignore_duplicate_error: Annotated[bool, PropertyInfo(alias="ignoreDuplicateError")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3UpdatePreferencesResponse", "Banner", "Base", "BaseAssistantCustomStyle", "Email", "Folder"]


class Banner(BaseModel):
    id: str

    link: Optional[str] = None

    name: str

    type: Literal["success", "info", "warning", "error"]


class BaseAssistantCustomStyle(BaseModel):
    id: str

    instructions: str

    name: str


class Base(BaseModel):
    assistant_custom_styles: List[BaseAssistantCustomStyle] = FieldInfo(alias="assistantCustomStyles")

    assistant_style_selection: Union[Literal["default", "concise", "tutor", "thorough", "skeptical"], str] = FieldInfo(
        alias="assistantStyleSelection"
    )

    default_private_paper_sidebar_tab: Optional[Literal["assistant", "notes", "similar"]] = FieldInfo(
        alias="defaultPrivatePaperSidebarTab", default=None
    )

    default_public_paper_sidebar_tab: Optional[Literal["comments", "assistant", "similar", "notes", "social"]] = (
        FieldInfo(alias="defaultPublicPaperSidebarTab", default=None)
    )

    feed_sort: Literal["Hot", "Comments", "Views", "Likes", "GitHub", "Twitter (X)", "Recommended"] = FieldInfo(
        alias="feedSort"
    )

    is_dark_mode_enabled: bool = FieldInfo(alias="isDarkModeEnabled")

    is_debug_mode_enabled: bool = FieldInfo(alias="isDebugModeEnabled")

    is_members_sidebar_visible: bool = FieldInfo(alias="isMembersSidebarVisible")

    preferred_language: Optional[
        Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ]
    ] = FieldInfo(alias="preferredLanguage", default=None)

    preferred_llm_model: Optional[str] = FieldInfo(alias="preferredLlmModel", default=None)

    reading_mode_enabled: bool = FieldInfo(alias="readingModeEnabled")

    show_model_thinking: bool = FieldInfo(alias="showModelThinking")

    tooling_pane_width: Optional[float] = FieldInfo(alias="toolingPaneWidth", default=None)

    web_search: Literal["off", "full"] = FieldInfo(alias="webSearch")


class Email(BaseModel):
    bounced: bool

    direct_notifications: bool = FieldInfo(alias="directNotifications")

    relevant_activity: bool = FieldInfo(alias="relevantActivity")


class Folder(BaseModel):
    folder_id: str = FieldInfo(alias="folderId")

    opened: bool


class V3UpdatePreferencesResponse(BaseModel):
    banners: List[Banner]

    base: Base

    email: Email

    folders: List[Folder]



from __future__ import annotations

import os
import inspect
import traceback
import contextlib
from typing import Any, TypeVar, Iterator, Sequence, cast
from datetime import date, datetime
from typing_extensions import Literal, get_args, get_origin, assert_type

from alphaxiv_cat._types import Omit, NoneType
from alphaxiv_cat._utils import (
    is_dict,
    is_list,
    is_list_type,
    is_union_type,
    extract_type_arg,
    is_sequence_type,
    is_annotated_type,
    is_type_alias_type,
)
from alphaxiv_cat._compat import PYDANTIC_V1, field_outer_type, get_model_fields
from alphaxiv_cat._models import BaseModel

BaseModelT = TypeVar("BaseModelT", bound=BaseModel)


def assert_matches_model(model: type[BaseModelT], value: BaseModelT, *, path: list[str]) -> bool:
    for name, field in get_model_fields(model).items():
        field_value = getattr(value, name)
        if PYDANTIC_V1:
            # in v1 nullability was structured differently
            # https://docs.pydantic.dev/2.0/migration/#required-optional-and-nullable-fields
            allow_none = getattr(field, "allow_none", False)
        else:
            allow_none = False

        assert_matches_type(
            field_outer_type(field),
            field_value,
            path=[*path, name],
            allow_none=allow_none,
        )

    return True


# Note: the `path` argument is only used to improve error messages when `--showlocals` is used
def assert_matches_type(
    type_: Any,
    value: object,
    *,
    path: list[str],
    allow_none: bool = False,
) -> None:
    if is_type_alias_type(type_):
        type_ = type_.__value__

    # unwrap `Annotated[T, ...]` -> `T`
    if is_annotated_type(type_):
        type_ = extract_type_arg(type_, 0)

    if allow_none and value is None:
        return

    if type_ is None or type_ is NoneType:
        assert value is None
        return

    origin = get_origin(type_) or type_

    if is_list_type(type_):
        return _assert_list_type(type_, value)

    if is_sequence_type(type_):
        assert isinstance(value, Sequence)
        inner_type = get_args(type_)[0]
        for entry in value:  # type: ignore
            assert_type(inner_type, entry)  # type: ignore
        return

    if origin == str:
        assert isinstance(value, str)
    elif origin == int:
        assert isinstance(value, int)
    elif origin == bool:
        assert isinstance(value, bool)
    elif origin == float:
        assert isinstance(value, float)
    elif origin == bytes:
        assert isinstance(value, bytes)
    elif origin == datetime:
        assert isinstance(value, datetime)
    elif origin == date:
        assert isinstance(value, date)
    elif origin == object:
        # nothing to do here, the expected type is unknown
        pass
    elif origin == Literal:
        assert value in get_args(type_)
    elif origin == dict:
        assert is_dict(value)

        args = get_args(type_)
        key_type = args[0]
        items_type = args[1]

        for key, item in value.items():
            assert_matches_type(key_type, key, path=[*path, "<dict key>"])
            assert_matches_type(items_type, item, path=[*path, "<dict item>"])
    elif is_union_type(type_):
        variants = get_args(type_)

        try:
            none_index = variants.index(type(None))
        except ValueError:
            pass
        else:
            # special case Optional[T] for better error messages
            if len(variants) == 2:
                if value is None:
                    # valid
                    return

                return assert_matches_type(type_=variants[not none_index], value=value, path=path)

        for i, variant in enumerate(variants):
            try:
                assert_matches_type(variant, value, path=[*path, f"variant {i}"])
                return
            except AssertionError:
                traceback.print_exc()
                continue

        raise AssertionError("Did not match any variants")
    elif issubclass(origin, BaseModel):
        assert isinstance(value, type_)
        assert assert_matches_model(type_, cast(Any, value), path=path)
    elif inspect.isclass(origin) and origin.__name__ == "HttpxBinaryResponseContent":
        assert value.__class__.__name__ == "HttpxBinaryResponseContent"
    else:
        assert None, f"Unhandled field type: {type_}"


def _assert_list_type(type_: type[object], value: object) -> None:
    assert is_list(value)

    inner_type = get_args(type_)[0]
    for entry in value:
        assert_type(inner_type, entry)  # type: ignore


@contextlib.contextmanager
def update_env(**new_env: str | Omit) -> Iterator[None]:
    old = os.environ.copy()

    try:
        for name, value in new_env.items():
            if isinstance(value, Omit):
                os.environ.pop(name, None)
            else:
                os.environ[name] = value

        yield None
    finally:
        os.environ.clear()
        os.environ.update(old)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .mcp import (
    McpResource,
    AsyncMcpResource,
    McpResourceWithRawResponse,
    AsyncMcpResourceWithRawResponse,
    McpResourceWithStreamingResponse,
    AsyncMcpResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "McpResource",
    "AsyncMcpResource",
    "McpResourceWithRawResponse",
    "AsyncMcpResourceWithRawResponse",
    "McpResourceWithStreamingResponse",
    "AsyncMcpResourceWithStreamingResponse",
]
